import boto3
import os
from config import access_key,endpoint, secret_key , bucket_name

session = boto3.session.Session()

s3_client = session.client(
    service_name='s3',
    aws_access_key_id=access_key,
    aws_secret_access_key=secret_key,
    endpoint_url=endpoint,
    )

# file_name = "carpet_staticData.tar.gz"
object_name = "sourceList"


def uploader(file_name,bucket_name, object_name=None, ExtraArgs=None):
    if object_name is None:
        object_name=file_name
    s3_client.upload_file(file_name, bucket_name, object_name, ExtraArgs)

    return("https://{}.s3.ir-thr-at1.arvanstorage.com/{}".format(bucket_name,object_name))


# url = uploader(file_name, bucket_name, object_name, ExtraArgs={'ACL':'public-read'})

# print(url)
s3_resource = boto3.resource(
        's3',
        aws_access_key_id=access_key,
        aws_secret_access_key=secret_key,
        endpoint_url=endpoint
    )
bucket = s3_resource.Bucket('git')
download_path = "inja/"+object_name
print(download_path)
bucket.download_file(
            object_name,
            download_path
        )


import boto3
from dotenv import load_dotenv
import os
import typer


app = typer.Typer()

class Storage():
    def __init__(self):
        load_dotenv()
        access_key =os.getenv("access_key")
        secret_key = os.getenv('secret_key')
        endpoint = os.getenv('endpoint')
        self.bucket_name = os.getenv("bucket_name")
        session = boto3.session.Session()
        self.s3_client = session.client(
            service_name='s3',
            aws_access_key_id=access_key,
            aws_secret_access_key=secret_key,
            endpoint_url=endpoint,
            )
        self.s3_resource = boto3.resource(
        's3',
        aws_access_key_id=access_key,
        aws_secret_access_key=secret_key,
        endpoint_url=endpoint
    )
    def downloader(self):
        pass
    def uploader(self,file_name,bucket_name= None, object_name=None, ExtraArgs=None):
        
        if bucket_name is None:
            bucket_name = self.bucket_name
        if object_name is None:
            object_name=file_name
        self.s3_client.upload_file(file_name, bucket_name, object_name, ExtraArgs)
        return("https://{}.s3.ir-thr-at1.arvanstorage.com/{}".format(bucket_name,object_name))
        
    def unsignedDownloader(self):
        pass
    def unsignedUploader(self):
        pass



import os 
from dotenv import load_dotenv
load_dotenv()
access_key =os.getenv("access_key")
secret_key = os.getenv('secret_key')

endpoint = os.getenv('endpoint')

bucket_name = os.getenv("bucket_name")


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nemosyne']

package_data = \
{'': ['*']}

install_requires = \
['CacheControl==0.12.6',
 'appdirs==1.4.3',
 'boto3==1.17.96',
 'botocore==1.20.96',
 'certifi==2019.11.28',
 'chardet==3.0.4',
 'click==7.1.2',
 'colorama==0.4.3',
 'contextlib2==0.6.0',
 'distlib==0.3.0',
 'distro==1.4.0',
 'html5lib==1.0.1',
 'idna==2.8',
 'ipaddr==2.2.0',
 'jmespath==0.10.0',
 'lockfile==0.12.2',
 'msgpack==0.6.2',
 'packaging==20.3',
 'pep517==0.8.2',
 'progress==1.5',
 'pyparsing==2.4.6',
 'python-dateutil==2.8.1',
 'python-dotenv==0.17.1',
 'pytoml==0.1.21',
 'requests==2.22.0',
 'retrying==1.3.3',
 's3transfer==0.4.2',
 'six==1.14.0',
 'typer==0.3.2',
 'urllib3==1.25.8',
 'webencodings==0.5.1']

entry_points = \
{'console_scripts': ['nemosyne = nemosyne.main:app']}

setup_kwargs = {
    'name': 'nemosyne',
    'version': '0.0.1',
    'description': 'nemosyne (aka [Mnemosyne](https://en.wikipedia.org/wiki/Mnemosyne)) is an S3 command-line manager.WIP',
    'long_description': 'nemosyne (aka [Mnemosyne](https://en.wikipedia.org/wiki/Mnemosyne)) is an S3 command-line manager.\n',
    'author': 'Ali Tavallaie',
    'author_email': 'a.tavallaie@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
